from .darkknight import DarkKnight
from .ftp import Ftp
from .ftps import Ftps
from .ftps_toucan import Ftps_toucan
from .geolocator import GeoLocator
from .git import Git
from .gsheet import Gsheet
from .healthcheck import HealthCheck
from .email import Email
from .mongo import Mongo
from .pdf import Pdf
from .plot import Plot
from .html import Html
from .cityfalcon import Cityfalcon
from .prediction import Prediction
from .sentiment_analysis import SentimentAnalysis
from .toucan import Toucan
from airtable import Airtable

__version__ = "0.10.0"

darkknight = DarkKnight
airtable = Airtable
ftp = Ftp
ftps = Ftps
ftps_toucan = Ftps_toucan
git = Git
geoLocator = GeoLocator
gsheet = Gsheet
health_check = HealthCheck
email = Email
mongo = Mongo
pdf = Pdf
plot = Plot
html = Html
cityfalcon = Cityfalcon
prediction = Prediction
sentiment_analysis = SentimentAnalysis
toucan = Toucan
